@@ -21,7 +21,7 @@ comboGeneral <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
         return(.Call(`_RcppAlgos_CombinatoricsCnstrt`, v, m, repetition,
                      freqs, lower, upper, constraintFun, comparisonFun,
                      limitConstraints, TRUE, keepResults, Parallel,
-                     nThreads, pkgEnv$nThreads, tolerance))
+                     nThreads, pkgEnv$nThreads, tolerance, FALSE, FALSE))
     }
 }
 
@@ -39,6 +39,11 @@ comboSample <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
                  pkgEnv$nThreads, namedSample, FUN.VALUE))
 }
 
+comboRank <- function(..., v, repetition = FALSE, freqs = NULL) {
+    GetRank(..., v = v, repetition = repetition,
+            freqs = freqs, IsComb = TRUE)
+}
+
 comboCount <-  function(v, m = NULL, repetition = FALSE, freqs = NULL) {
     .Call(`_RcppAlgos_CombinatoricsCount`, v, m,
           repetition, freqs, TRUE);
@@ -55,8 +60,9 @@ comboIter <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
                       keepResults, FUN)
     IsCnstrd <- .Call(`_RcppAlgos_CheckConstrndCpp`, constraintFun,
                       comparisonFun, limitConstraints)
-    InitVals <- .Call(`_RcppAlgos_GetClassVals`, v, m, repetition, freqs,
-                      TRUE, FUN, nThreads, pkgEnv$nThreads, IsCnstrd)
+    InitVals <- .Call(`_RcppAlgos_GetClassVals`, v, m, repetition,
+                      freqs, TRUE, FUN, nThreads, pkgEnv$nThreads,
+                      IsCnstrd, FALSE, FALSE)
 
     if (RetValue == 1) {
         new("Combo", InitVals, Parallel)
